<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>Dupliquer</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>Étendre</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>Uniquement sur %1</translation>
    </message>
</context>
</TS>